@@ -1,4 +1,4 @@
-#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Y a une couillasse dans ton TLSCipherSuite '%s'"
+#define MSG_TLS_CIPHER_FAILED "TLS: Y a une couillasse dans ton TLSCipherSuite '%s'"
 #define MSG_TIMEOUT "Putain mais achete-toi des doigts"
 #define MSG_CAPABILITIES "Ton kernel m'a envoye chier"
 #define MSG_CLIENT_CLOSED_CNX "Le mec s'est casse"
@@ -215,12 +215,12 @@
 #define MSG_ALIASES_LIST "Si t'as la flemme, tu peux utiliser ces raccourcis :"
 #define MSG_PERUSER_MAX "T'es deja la %lu fois, j'en ai marre de voir ta gueule"
 #define MSG_IPV6_OK "Si t'es pas un batard, tu peux te connecter en IPv6."
-#define MSG_TLS_INFO "SSL/TLS: Direct, le scarla il deale du %s (%s) en %d bits !"
-#define MSG_TLS_WEAK "SSL/TLS: C'est quoi ce chiffrement de tafiole ?"
+#define MSG_TLS_INFO "TLS: Direct, le scarla il deale du %s (%s) en %d bits !"
+#define MSG_TLS_WEAK "TLS: C'est quoi ce chiffrement de tafiole ?"
 #define MSG_TLS_NEEDED "Ecoute-moi connard : t'as 10 secondes pour configurer\n" \
-    "ton client de merde en SSL/TLS. En attendant, degage."
+    "ton client de merde en TLS. En attendant, degage."
 #define MSG_ILLEGAL_CHARSET "Ton jeu de caractere il puxore grave."
-#define MSG_TLS_NO_CTX "SSL/TLS: contexte introuvable. Cassos."
+#define MSG_TLS_NO_CTX "TLS: contexte introuvable. Cassos."
 #define MSG_PROT_OK "Niveau de super mega protection : \"%s\""
 #define MSG_PROT_PRIVATE_NEEDED "Le reglage envoye avec PROT est une grosse daube que je refuse pour transmettre des donnees."
 #define MSG_PROT_UNKNOWN_LEVEL "C'est quoi ce niveau de protection %s ? Pas compris. Je vais donc choisir \"%s\""
